#include "ContextFreePluginExample.h"
#include <QDebug>
#include <QMessageBox>

using namespace contextfreepluginexample;

// This method is called when the plugin is opened
void ContextFreePluginExample::opened(cubepluginapi::ContextFreeServices* service)
{
    this->service = service;

    // Create a button and add it to Cube's main widget
    QPushButton* button = new QPushButton("Load Cube File", service->getWidget());
    QObject::connect(button, &QPushButton::clicked, this, &ContextFreePluginExample::startAction);
}

// This method is called when the plugin is closed
void ContextFreePluginExample::closed()
{
    qDebug() << "Context free plugin closed";
    // Clean up resources
}

// This method will be called when the user clicks the "Load Cube File" button
void ContextFreePluginExample::startAction()
{
    QString openFileName = QFileDialog::getOpenFileName(
        service->getWidget(),
        tr("Choose a file to open"),
        "",
        tr("Cube3/4 files (*.cube *.cube.gz *.cubex);;All files (*.*)")
    );

    if (!openFileName.isEmpty()) {
        std::vector<std::string> fileNames;
        fileNames.push_back(openFileName.toStdString());
        cube::CubeProxy* cube = cube::CubeProxy::create(cube::ALGORITHM_EMPTY, fileNames);
        service->openCube(cube);  // Cube is opened and will be deleted automatically when closed
    }
}

// This method sets the plugin version
void ContextFreePluginExample::version(int& major, int& minor, int& bugfix) const
{
    major = 1;
    minor = 0;
    bugfix = 0;
}

// This method returns the plugin name
QString ContextFreePluginExample::name() const
{
    return "Context Free Demo";
}

// This method returns help text for the plugin
QString ContextFreePluginExample::getHelpText() const
{
    return "This is a demo plugin that allows loading Cube files from the file system.";
}

// Export the plugin for Qt versions < 5.0 (for backward compatibility)
#if QT_VERSION < 0x050000
Q_EXPORT_PLUGIN2(ContextFreePluginExample, ContextFreePluginExample)
#endif
