#include "CubeJsonPlugin.h"
#include <QMessageBox> // Required for displaying message boxes

CubeJsonPlugin::CubeJsonPlugin() : widget_(nullptr), label_(nullptr), exportButton_(nullptr), service_(nullptr) {}

bool CubeJsonPlugin::cubeOpened(cubepluginapi::PluginServices* service) {
    // Initialize plugin and create GUI components
    this->service_ = service;

    // Create main widget
    widget_ = new QWidget();
    QVBoxLayout* layout = new QVBoxLayout(widget_);

    // Add label to display selected item's name
    label_ = new QLabel("System Tree Visualization");
    layout->addWidget(label_);

    // Add export button for JSON functionality
    exportButton_ = new QPushButton("Export Selected Item to JSON");
    layout->addWidget(exportButton_);

    // Connect signals for tree item selection and button clicks
    connect(service, &cubepluginapi::PluginServices::treeItemIsSelected, this, &CubeJsonPlugin::treeItemIsSelected);
    connect(exportButton_, &QPushButton::clicked, this, &CubeJsonPlugin::exportJson);

    // Add the plugin as a tab in CubeGUI
    service->addTab(cubegui::SYSTEM, this);
    return true;
}

void CubeJsonPlugin::cubeClosed() {
    // Clean up resources
    delete widget_;
    widget_ = nullptr;
    label_ = nullptr;
    exportButton_ = nullptr;
    service_ = nullptr;
}

QString CubeJsonPlugin::name() const {
    return "CubeJsonPlugin";
}

void CubeJsonPlugin::version(int& major, int& minor, int& bugfix) const {
    major = 1;
    minor = 0;
    bugfix = 0;
}

QString CubeJsonPlugin::getHelpText() const {
    return "This plugin displays system tree data and allows exporting the selected item to JSON.";
}

QString CubeJsonPlugin::label() const {
    return "System Tree JSON";
}

QWidget* CubeJsonPlugin::widget() {
    return widget_;
}

void CubeJsonPlugin::treeItemIsSelected(cubepluginapi::TreeItem* item) {
    // Update the label with the name of the selected item
    if (item) {
        selectedItemName_ = item->getName();
        label_->setText("Selected Item: " + selectedItemName_);
    }
}

void CubeJsonPlugin::exportJson() {
    // Check if an item is selected
    if (selectedItemName_.isEmpty()) {
        QMessageBox::warning(widget_, "Export Error", "No tree item is selected.");
        return;
    }

    // Create JSON object
    QJsonObject json;
    json["selected_item_name"] = selectedItemName_;

    // Open file dialog for saving the JSON file
    QString filePath = QFileDialog::getSaveFileName(widget_, "Save JSON File", "", "JSON Files (*.json)");
    if (filePath.isEmpty()) return;

    // Write JSON data to the file
    QFile file(filePath);
    if (file.open(QIODevice::WriteOnly)) {
        file.write(QJsonDocument(json).toJson());
        file.close();
        QMessageBox::information(widget_, "Export Successful", "JSON file saved successfully!");
    } else {
        QMessageBox::warning(widget_, "Export Error", "Failed to save JSON file.");
    }
}