#include "SystemTreeParser.h"
#include <QJsonObject>
#include <QJsonArray> // This includes QJsonArray support

QJsonObject SystemTreeParser::parseSystemTree(cube::SystemTreeNode* root) {
    QJsonObject nodeObj;
    if (!root) return nodeObj;

    nodeObj["name"] = QString::fromStdString(root->get_name());

    QJsonArray children;
    for (auto* child : root->get_children()) {
        if (auto* systemNode = dynamic_cast<cube::SystemTreeNode*>(child)) {
            children.append(parseSystemTree(systemNode));
        }
    }
    nodeObj["children"] = children;
    nodeObj["processes"] = parseProcesses(root->get_groups());

    return nodeObj;
}

QJsonArray SystemTreeParser::parseProcesses(const std::vector<cube::LocationGroup*>& processGroups) {
    QJsonArray processArray;

    for (const auto* group : processGroups) {
        QJsonObject processObj;
        processObj["id"] = static_cast<int>(group->get_id());
        processObj["name"] = QString::fromStdString(group->get_name());

        QJsonArray threadArray;
        for (auto* child : group->get_children()) {
            if (auto* thread = dynamic_cast<cube::Location*>(child)) {
                QJsonObject threadObj;
                threadObj["id"] = static_cast<int>(thread->get_id());
                threadObj["name"] = QString::fromStdString(thread->get_name());
                threadArray.append(threadObj);
            }
        }
        processObj["threads"] = threadArray;

        processArray.append(processObj);
    }

    return processArray;
}

QJsonArray SystemTreeParser::parseThreads(const std::vector<cube::Location*>& threads) {
    QJsonArray threadArray;

    for (const auto* thread : threads) {
        QJsonObject threadObj;
        threadObj["id"] = static_cast<int>(thread->get_id());
        threadObj["name"] = QString::fromStdString(thread->get_name());
        threadArray.append(threadObj);
    }

    return threadArray;
}