#ifndef SYSTEMTREEPARSER_H
#define SYSTEMTREEPARSER_H

#include "CubeSystemTreeNode.h" // Include for system tree node definitions
#include "CubeLocationGroup.h"  // Include for process group definitions
#include "CubeLocation.h"       // Include for thread definitions
#include <QJsonObject>
#include <QJsonArray>
#include <vector>

/**
 * @brief The SystemTreeParser class provides methods to parse the Cube system tree structure
 *        into a JSON representation.
 */
class SystemTreeParser {
public:
    /**
     * @brief Parses the system tree structure starting from the root node.
     * @param root Pointer to the root system tree node.
     * @return JSON object representing the system tree structure.
     */
    static QJsonObject parseSystemTree(cube::SystemTreeNode* root);

private:
    /**
     * @brief Parses the processes within a system tree node.
     * @param processGroups Vector of pointers to process groups.
     * @return JSON array representing the processes.
     */
    static QJsonArray parseProcesses(const std::vector<cube::LocationGroup*>& processGroups);

    /**
     * @brief Parses the threads within a process group.
     * @param threads Vector of pointers to threads.
     * @return JSON array representing the threads.
     */
    static QJsonArray parseThreads(const std::vector<cube::Location*>& threads);
};

#endif // SYSTEMTREEPARSER_H